@@ -411,7 +411,7 @@ class MessageProcessor:
         else:
             metadata["type"] = "text"
 
-        if metadata and metadata.get("errorMessage"):
+        if metadata and metadata.get("error_message"):
             metadata["error"] = True
 
         if metadata and metadata.get("error"):
