@@ -472,24 +472,12 @@ def create_app(
             }
         )
 
-    @app.get("/profilerStats")
-    async def profiler_state(request: Request):
-        """ Print the stats of the profiler """
-        app.profiler.stop()
-        return response.html(app.profiler.output_html())
-
-    @app.get("/startProfiler")
-    async def profiler_state(request: Request):
-        """ Print the stats of the profiler """
-        app.profiler.start()
-        return response.text("Profiler started")
-
     @app.get("/healthz/live")
     async def live(request: Request):
         """Check if the server is running and responds with the version."""
         try:
             if endpoints.tracker_store:
-                resp = app.agent.tracker_store.is_healthy()
+                resp = await app.agent.tracker_store.is_healthy()
 
                 if not resp:
                     logger.error({"event": "HEALTH_CHECK", "message": "Tracker store is unhealthy."})
